@@ -16,12 +16,11 @@
 Changelog
 ---------
 
-V1.0.1: MC, Oxford, 21 April 2020
-    - Updated documentation.
-
 V1.0.0: Michele Cappellari, Oxford, 08 November 2019
     - Written and tested.
 
+The latest changelog is given in the package file CHANGELOG.
+
 """
 import numpy as np
 import matplotlib.pyplot as plt
@@ -141,7 +140,7 @@ def integand_tan_dth_pot(u, r, th, dens_pot, sigma_pot, qintr_pot):
     https://ui.adsabs.harvard.edu/abs/2020MNRAS.494.4819C
 
     """
-    # DE change of variables for Chandrasekhar u-integral [-3,3] -> [0,inf]
+    # DE change of variables for Chandrasekhar u-integral [-3, 3] -> [0, inf]
     x = np.exp(np.sinh(u)*np.pi/2)
     duds = x*np.cosh(u)*np.pi/2
     u = x[:, None]
@@ -175,13 +174,13 @@ def integrand_sph(s, t, r, th, dens_lum, sigma_lum, qintr_lum,
     s2_pot = (sigma_pot**2)[None, :, None]
     qintr_pot = qintr_pot[None, :, None]
 
-    # DE Change of variables for Chandrasekhar u-integral [-3,3] -> [0,inf]
+    # DE Change of variables for Chandrasekhar u-integral [-3, 3] -> [0, inf]
     x = np.exp(np.sinh(s)*np.pi/2)
     duds = x*np.cosh(s)*np.pi/2
     u = x[None, None, :]
 
     # TANH Change of variables for Jeans r1-integral
-    # np.log([1e-6, 3*np.max(sigma_lum)]) -> [r,inf]
+    # np.log([1e-6, 3*np.max(sigma_lum)]) -> [r, inf]
     drdt = np.exp(t)
     r1 = r + drdt[None, None, :]
 
@@ -490,6 +489,9 @@ class jam_axi_intr:
     nang: int, optional
         The number of linearly-spaced intervals in the eccentric anomaly at
         which the model is evaluated before interpolation (default: ``nang=10``).
+    nodots: bool, optional
+        Set to ``True`` to hide the dots indicating the centers of the bins in
+        the two-dimensional map (default ``False``).
     nrad: int, optional
         The number of logarithmically spaced radial positions at which the
         model is evaluated before interpolation. One may want to increase this
@@ -547,8 +549,8 @@ class jam_axi_intr:
 
         The mean velocity can be computed as ``vphi = np.sqrt(v2phi - sig2phi)``
 
-        NOTE: I return squared velocities instead of taking the square root, 
-        to allow for negative values.
+        NOTE: I return squared velocities instead of taking the square root,
+        to allow for negative values (unphysical solutions).
     .flux: array_like  with shape (p,)
         Vector with the MGE luminosity density at each ``(R, z)`` location in
         ``Lsun/pc^3``, used to plot the isophotes on the model results.
@@ -567,7 +569,7 @@ class jam_axi_intr:
                  mbh, Rbin, zbin, align='cyl, ', beta=None, data=None,
                  epsrel=1e-2, errors=None, gamma=None, goodbins=None,
                  interp=True, ml=None, nang=10, nrad=20, plot=True,
-                 proj_cyl=False, quiet=False, rbh=1, **kwargs):
+                 proj_cyl=False, quiet=False, rbh=1, nodots=False):
 
         assert align in ['sph', 'cyl'], "`align` must be 'sph' or 'cyl'"
         assert (ml is None) or (ml > 0), "The input `ml` must be positive"
@@ -618,7 +620,7 @@ class jam_axi_intr:
             interp, proj_cyl, align)
 
         if not quiet:
-            print(f'jam_axi_{align}_intr elapsed time (sec): {clock() - t:.2f}')
+            print(f'jam_axi_intr_{align} elapsed time (sec): {clock() - t:.2f}')
 
         if data is None:
 
@@ -655,11 +657,11 @@ class jam_axi_intr:
         self.goodbins = goodbins
 
         if plot and (data is not None):
-            self.plot(**kwargs)
+            self.plot(nodots)
 
 ##############################################################################
 
-    def plot(self, **kwargs):
+    def plot(self, nodots=False):
         """ Data-model comparison for jam_axi_intr """
 
         plt.figure('jam')
@@ -677,10 +679,10 @@ class jam_axi_intr:
         for j, (d, m, t) in enumerate(zip(self.data, np.sqrt(self.model.clip(0)), txt)):
             plt.sca(ax[j, 0])
             mn, mx = np.percentile(d, [1, 99])
-            plot_velfield(self.Rbin, self.zbin, d, vmin=mn, vmax=mx, flux=self.flux, **kwargs)
+            plot_velfield(self.Rbin, self.zbin, d, vmin=mn, vmax=mx, flux=self.flux, nodots=nodots)
 
             plt.sca(ax[j, 1])
             plot_velfield(self.Rbin, self.zbin, m, vmin=mn, vmax=mx, flux=self.flux,
-                          colorbar=1, label=t, **kwargs)
+                          colorbar=1, label=t, nodots=nodots)
 
 ##############################################################################
