@@ -16,12 +16,11 @@
 Changelog
 ---------
 
-V1.0.1: MC, Oxford, 21 April 2020
-    - Updated documentation.
-
 V1.0.0: Michele Cappellari, Oxford, 08 November 2019
     - Written and tested.
 
+The latest changelog is given in the package file CHANGELOG.
+
 """
 
 import numpy as np
@@ -33,6 +32,7 @@ from plotbin.plot_velfield import plot_velfield
 from plotbin.symmetrize_velfield import symmetrize_velfield
 
 from jampy.jam_axi_intr import mom_interp
+from jampy.legacy.jam_axi_rms import surf_v2los
 
 ##############################################################################
 
@@ -44,7 +44,8 @@ def vmom_proj(x1, y1, inc,
     This routine gives the projected first velocity moments
     and the second velocity moments tensor for a JAM model with
     either cylindrically or spherically-aligned velocity ellipsoid.
-    The projection formulas given below are described in Sec.3 of
+    The projection formulas given below are described in
+    Sec.3 and the numerical quadrature in Sec.6.2 of
     Cappellari (2020, MNRAS, 494, 4819; hereafter C20)
     https://ui.adsabs.harvard.edu/abs/2020MNRAS.494.4819C
 
@@ -73,7 +74,7 @@ def vmom_proj(x1, y1, inc,
 
     mom = irp.get_moments(R.ravel(), z.ravel())
     sig2r, sig2th, sig2phi, v2phi, nu = np.reshape(mom, (5,) + z.shape)
-    vphi = np.sqrt((v2phi - sig2phi).clip(0))
+    vphi = np.sqrt((v2phi - sig2phi).clip(0))   # Clip unphysical solutions
     diag = np.array([sig2r, sig2th, v2phi])
     zero = np.zeros_like(nu)
     one = np.ones_like(nu)
@@ -97,9 +98,9 @@ def vmom_proj(x1, y1, inc,
 
     surf = nu @ dxdt                # DE quadrature
     nu_vlos = nu*integ1 @ dxdt      # DE quadrature
-    nu_v2rms = nu*integ2 @ dxdt     # DE quadrature
+    nu_v2los = nu*integ2 @ dxdt     # DE quadrature
     vel = nu_vlos/surf
-    vel2 = nu_v2rms/surf
+    vel2 = nu_v2los/surf
 
     return vel, vel2
 
@@ -149,7 +150,7 @@ def psf_conv(x, y, inc_deg,
              surf_lum, sigma_lum, qobs_lum,
              surf_pot, sigma_pot, qobs_pot,
              beta, gamma, moment, align, sigmaPsf, normPsf,
-             pixSize, pixAng, step, nrad, nang, nlos, epsrel, interp):
+             pixSize, pixAng, step, nrad, nang, nlos, epsrel, interp, analytic_los):
     """
     This routine gives the velocity moment after convolution with a PSF.
     The convolution is done using interpolation of the model on a
@@ -213,14 +214,22 @@ def psf_conv(x, y, inc_deg,
 
     # The model computation is only performed on the polar grid
     # which is then used to interpolate the values at any other location
-    vel, vel2 = vmom_proj(x_pol, y_pol, inc,
-                          dens_lum, sigma_lum, qintr_lum,
-                          dens_pot, sigma_pot, qintr_pot,
-                          beta, gamma, nrad, nang, nlos, epsrel, align)
-
-    model = {'xx': vel2[0, 0], 'yy': vel2[1, 1], 'zz': vel2[2, 2],
-             'xy': vel2[0, 1], 'xz': vel2[0, 2], 'yz': vel2[1, 2],
-             'x': vel[0], 'y': vel[1], 'z': vel[2]}[moment]
+    if analytic_los:
+        # Analytic line-of-sight integral
+        sb_mu2 = surf_v2los(x_pol, y_pol, inc,
+                            dens_lum, sigma_lum, qintr_lum,
+                            dens_pot, sigma_pot, qintr_pot, beta, moment)
+        model = sb_mu2/mge_surf(x_pol, y_pol, surf_lum, sigma_lum, qobs_lum)
+        vel = vel2 = None
+    else:
+        # Numeric line-of-sight integral
+        vel, vel2 = vmom_proj(x_pol, y_pol, inc,
+                              dens_lum, sigma_lum, qintr_lum,
+                              dens_pot, sigma_pot, qintr_pot,
+                              beta, gamma, nrad, nang, nlos, epsrel, align)
+        model = {'xx': vel2[0, 0], 'yy': vel2[1, 1], 'zz': vel2[2, 2],
+                 'xy': vel2[0, 1], 'xz': vel2[0, 2], 'yz': vel2[1, 2],
+                 'x': vel[0], 'y': vel[1], 'z': vel[2]}[moment]
 
     if interp and psf_convolution:  # PSF convolution
 
@@ -231,7 +240,8 @@ def psf_conv(x, y, inc_deg,
         x_car, y_car = np.meshgrid(x1, y1)  # Cartesian grid for convolution
         mge_car = mge_surf(x_car, y_car, surf_lum, sigma_lum, qobs_lum)
 
-        # Interpolate moment over cartesian grid
+        # Interpolate moment over cartesian grid.
+        # Interpolating "nu_v2/surf" instead of "nu_v2" or "np.log(nu_v2)" reduces interpolation error.
         r1 = 0.5*np.log(x_car**2 + (y_car/qmed)**2)  # Log elliptical radius of cartesian grid
         e1 = np.arctan2(np.abs(y_car/qmed), np.abs(x_car))    # Eccentric anomaly of cartesian grid
         model_car = mge_car*bilinear_interpolate(logRad, ang, model.reshape(nang, nrad), r1, e1)
@@ -320,17 +330,20 @@ class jam_axi_proj:
     .. code-block:: python
 
         jam = jam_axi_proj(
-                 surf_lum, sigma_lum, qobs_lum, surf_pot, sigma_pot, qobs_pot,
+                surf_lum, sigma_lum, qobs_lum, surf_pot, sigma_pot, qobs_pot,
                  inc, mbh, distance, xbin, ybin, beta=None, gamma=None,
-                 errors=None, flux_obs=None, goodbins=None, kappa=None, ml=None,
-                 nang=10, normpsf=1., nrad=20, pixang=0., pixsize=0., plot=True,
-                 quiet=False, rbh=0.01, data=None, sigmapsf=0., step=0.,
-                 moment='zz', vmax=None, vmin=None, nlos=65, epsrel=1e-2,
-                 align='cyl', kwargs={})
+                 errors=None, flux_obs=None, goodbins=None, interp=True,
+                 kappa=None, ml=None, nang=10, normpsf=1., nrad=20, pixang=0.,
+                 pixsize=0., plot=True, quiet=False, rbh=0.01, data=None,
+                 sigmapsf=0., step=0., moment='zz', vmax=None, vmin=None,
+                 nlos=150, epsrel=1e-2, align='cyl', analytic_los=True,
+                 nodots=False)
 
         vrms = jam.model  # with moment='zz' the output is the LOS Vrms
 
-        jam.plot()   # Generate data/model comparison
+        jam.plot()   # Generate data/model comparison when data is given
+
+    See more examples in the ``jampy/examples`` folder inside ``site-packages``.
 
     Input Parameters
     ----------------
@@ -453,6 +466,18 @@ class jam_axi_proj:
         the same (equation 52 of Cappellari 2008, MNRAS).
         When ``kappa=1`` the model first velocity moments are output without
         any scaling.
+    analytic_los: bool, optional
+        This is ``True`` (default) if the line-of-sight integral is performed
+        analytically and ``False`` if it is done via numerical quadrature.
+
+        An analytic integral is only possible with ``align='cyl'`` and only for
+        the second velocity moments. For this reason, when comparing the two
+        second-moment solutions with ``align='cyl'`` and ``align='sph'``, it
+        may be preferable to set ``analytic_los=False`` to ensure that
+        numerical interpolation error is exactly the same in both cases.
+
+        When ``align='sph'``, or when the user requests a first velocity
+        moment, this keyword is automatically set to ``False``.
     ml: float, optional
         Mass-to-light ratio (M/L) to multiply the values given by ``surf_pot``.
         Setting this keyword is completely equivalent to multiplying the
@@ -464,16 +489,19 @@ class jam_axi_proj:
         also scaled and becomes ``mbh*ml``.
     nlos: int (optional)
         Number of values used for the numerical line-of-sight quadrature.
-        (default ``nlos=65``)
+        (default ``nlos=150``)
+    nang: int, optional
+        The number of linearly-spaced intervals in the eccentric anomaly at
+        which the model is evaluated before interpolation and PSF convolution.
+        (default: ``nang=10``)
+    nodots: bool, optional
+        Set to ``True`` to hide the dots indicating the centers of the bins in
+        the two-dimensional map (default ``False``).
     normpsf: array_like with shape (q,)
         fraction of the total PSF flux contained in the circular Gaussians
         describing the PSF of the kinematic observations.
         The PSF will be used for seeing convolution of the model kinematics.
         It has to be ``np.sum(normpsf) = 1``.
-    nang: int, optional
-        The number of linearly-spaced intervals in the eccentric anomaly at
-        which the model is evaluated before interpolation and PSF convolution.
-        (default: ``nang=10``)
     nrad: int, optional
         The number of logarithmically spaced radial positions at which the
         model is evaluated before interpolation and PSF convolution. One may
@@ -499,6 +527,10 @@ class jam_axi_proj:
         The gravitational potential is indistinguishable from a point source
         for ``radii > 2*rbh``, so the default ``rbh=0.01`` arcsec is appropriate
         in most current situations.
+
+        When using different units as input, e.g. pc instead of arcsec, one
+        should check that ``rbh`` is not too many order of magnitude smaller
+        than the spatial resolution of the data.
     data: array_like with shape (p,), optional
         observed first or second velocity moment used to fit the model.
 
@@ -614,20 +646,23 @@ class jam_axi_proj:
                  kappa=None, ml=None, nang=10, normpsf=1., nrad=20, pixang=0.,
                  pixsize=0., plot=True, quiet=False, rbh=0.01, data=None,
                  sigmapsf=0., step=0., moment='zz', vmax=None, vmin=None,
-                 nlos=65, epsrel=1e-2, align='cyl', **kwargs):
+                 nlos=150, epsrel=1e-2, align='cyl', analytic_los=True,
+                 nodots=False):
 
         str1 = ['x', 'y', 'z']
         str2 =  ['xx', 'yy', 'zz', 'xy', 'xz', 'yz']
         assert moment in str1 + str2, f"`moment` must be one of {str1 + str2}"
         assert align in ['sph', 'cyl'], "`align` must be 'sph' or 'cyl'"
         assert (ml is None) or (ml > 0), "The input `ml` must be positive"
+        if (not interp) or (moment in str1) or (align == 'sph'):
+            analytic_los = False
         if beta is None:
             beta = np.zeros_like(surf_lum)  # Anisotropy parameter beta = 1 - (sig_th/sig_r)**2
         if gamma is None:
             gamma = np.zeros_like(surf_lum)  # Anisotropy parameter beta = 1 - (sig_th/sig_r)**2
         assert surf_lum.size == sigma_lum.size == qobs_lum.size == beta.size, "The luminous MGE components do not match"
         assert surf_pot.size == sigma_pot.size == qobs_pot.size, "The total mass MGE components do not match"
-        assert xbin.size == ybin.size, "xbin and ybin do not match"
+        assert xbin.size == ybin.size, "`xbin` and `ybin` do not match"
         if data is not None:
             if errors is None:
                 if moment in str2:
@@ -639,7 +674,8 @@ class jam_axi_proj:
             else:
                 assert goodbins.dtype == bool, "goodbins must be a boolean vector"
                 assert np.any(goodbins), "goodbins must contain some True values"
-            assert xbin.size == data.size == errors.size == goodbins.size, "(rms, erms, goodbins) and (xbin, ybin) do not match"
+            assert xbin.size == data.size == errors.size == goodbins.size, \
+                "(rms, erms, goodbins) and (xbin, ybin) do not match"
 
         sigmapsf = np.atleast_1d(sigmapsf)
         normpsf = np.atleast_1d(normpsf)
@@ -663,6 +699,8 @@ class jam_axi_proj:
         # of a point-like mass, to 1% accuracy out to a radius 2*sigmaBH.
         # The error increases to 14% at 1*sigmaBH, independently of the BH mass.
         if mbh > 0:
+            tmp = np.concatenate([sigmapsf, [pixsize], sigma_lum])
+            assert rbh > 0.01*np.min(tmp[tmp > 0]), "`rbh` is too small"
             sigmaBH_pc = rbh*pc # Adopt for the BH just a very small size
             surfBH_pc = mbh/(2*np.pi*sigmaBH_pc**2)
             surf_pot_pc = np.append(surfBH_pc, surf_pot_pc) # Add Gaussian to potential only!
@@ -678,7 +716,7 @@ class jam_axi_proj:
             surf_lum_pc, sigma_lum_pc, qobs_lum,
             surf_pot_pc, sigma_pot_pc, qobs_pot,
             beta, gamma, moment, align, sigmaPsf_pc, normpsf,
-            pixSize_pc, pixang, step_pc, nrad, nang, nlos, epsrel, interp)
+            pixSize_pc, pixang, step_pc, nrad, nang, nlos, epsrel, interp, analytic_los)
 
         if moment in str2[:3]:
             model = np.sqrt(model.clip(0))  # sqrt and clip to allow for rounding errors
@@ -742,18 +780,19 @@ class jam_axi_proj:
             chi2 = ((d - m)**2).sum()/goodbins.sum()
 
         if not quiet:
-            print(f'jam_axi_{align}_{moment}_proj elapsed time sec: {clock() - t:.2f}')
+            print(f'jam_axi_proj_{align}_{moment} (analytic_los={analytic_los}) '
+                  f'elapsed time sec: {clock() - t:.2f}')
             if not psfConvolution:
-                txt = "No PSF convolution:"
+                txt = "No PSF/pixel convolution:"
                 if np.max(sigmapsf) == 0:
                     txt += " sigmapsf == 0;"
                 if pixsize == 0:
                     txt += " pixsize == 0;"
                 print(txt)
-            print(f'inc={inc:.3g}; beta[0]={beta[0]:.2g}; kappa={kappa:.2g}; '
-                  f'M/L={ml:.3g}; BH={mbh*ml:.2g}; chi2/DOF={chi2:.3g}')
+            print(f'inc={inc:#.3g}; beta[0]={beta[0]:#.2g}; kappa={kappa:#.2g}; '
+                  f'M/L={ml:#.3g}; BH={mbh*ml:#.2g}; chi2/DOF={chi2:#.3g}')
             mass = 2*np.pi*surf_pot_pc*qobs_pot*sigma_pot_pc**2
-            print(f'Total mass MGE (MSun): {(mass*ml).sum():.4g}')
+            print(f'Total mass MGE (MSun): {(mass*ml).sum():#.4g}')
 
         self.xbin = xbin
         self.ybin = ybin
@@ -771,11 +810,11 @@ class jam_axi_proj:
         self.vel2 = vel2
 
         if plot and (data is not None):
-            self.plot(**kwargs)
+            self.plot(nodots)
 
 ##############################################################################
 
-    def plot(self, **kwargs):
+    def plot(self, nodots=False):
 
         ok = self.goodbins
         str1 = ['x', 'y', 'z']
@@ -791,11 +830,11 @@ class jam_axi_proj:
 
         plt.clf()
         plt.subplot(121)
-        plot_velfield(self.xbin, self.ybin, data1, vmin=vmin, vmax=vmax, flux=self.flux_obs, **kwargs)
+        plot_velfield(self.xbin, self.ybin, data1, vmin=vmin, vmax=vmax, flux=self.flux_obs, nodots=nodots)
         plt.title(f"Input V$_{{{self.moment}}}$ moment")
 
         plt.subplot(122)
-        plot_velfield(self.xbin, self.ybin, self.model, vmin=vmin, vmax=vmax, flux=self.flux, **kwargs)
+        plot_velfield(self.xbin, self.ybin, self.model, vmin=vmin, vmax=vmax, flux=self.flux, nodots=nodots)
         plt.plot(self.xbin[~ok], self.ybin[~ok], 'ok', mec='white')
         plt.title(f"JAM$_{{\\rm{self.align}}}$ model")
         plt.tick_params(labelleft=False)
