@@ -1,5 +1,5 @@
 """
-    Copyright (C) 2003-2019, Michele Cappellari
+    Copyright (C) 2003-2020, Michele Cappellari
     E-mail: michele.cappellari_at_physics.ox.ac.uk
 
     Updated versions of the software are available from my web page
@@ -251,7 +251,7 @@ def vrms2(x, y, inc_deg,
         r1 = 0.5*np.log(xCar**2 + (yCar/qmed)**2) # Log elliptical radius of cartesian grid
         e1 = np.arctan2(np.abs(yCar/qmed), np.abs(xCar))    # Eccentric anomaly of cartesian grid
 
-        # # Division by mgePol before interpolation reduces interpolation error
+        # Division by mgePol before interpolation reduces interpolation error
         mgeCar = mge_surf(xCar, yCar, surf_lum, sigma_lum, qobs_lum)
         mgePol = mge_surf(xPol, yPol, surf_lum, sigma_lum, qobs_lum)
         wm2Car = mgeCar*bilinear_interpolate(logRad, ang, (wm2Pol/mgePol).reshape(nang, nrad), r1, e1)
@@ -640,9 +640,9 @@ def jam_axi_rms(surf_lum, sigma_lum, qobs_lum, surf_pot, sigma_pot, qobs_pot,
         chi2 = ((d - m*np.sqrt(ml))**2).sum() / goodbins.sum()
 
         if not quiet:
-            print(f'inc={inc:.1f} beta_z={beta[0]:.2f} M/L={ml:.3g} BH={mbh*ml:.2e} chi2/DOF={chi2:.3g}')
+            print(f'inc={inc:.1f} beta_z={beta[0]:.2f} M/L={ml:#.3g} BH={mbh*ml:.2e} chi2/DOF={chi2:#.3g}')
             mass = 2*np.pi*surf_pot_pc*qobs_pot*sigma_pot_pc**2
-            print(f'Total mass MGE: {np.sum(mass*ml):.4g}')
+            print(f'Total mass MGE: {np.sum(mass*ml):#.4g}')
 
         if plot:
 
