@@ -778,9 +778,9 @@ def jam_axi_vel(surf_lum, sigma_lum, qobs_lum, surf_pot, sigma_pot, qobs_pot,
         chi2 = np.sum(((vel[goodbins]-velModel[goodbins])/evel[goodbins])**2) / goodbins.sum()
 
         if not quiet:
-            print('inc=%.1f kappa=%.2f beta_z=%.2f BH=%.2e chi2/DOF=%.3g' % (inc, kappa[0], beta[0], mbh, chi2))
+            print('inc=%.1f kappa=%.2f beta_z=%.2f BH=%.2e chi2/DOF=%#.3g' % (inc, kappa[0], beta[0], mbh, chi2))
             mass = 2*np.pi*surf_pot_pc*qobs_pot*sigma_pot_pc**2
-            print('Total mass MGE %.4g:' % np.sum(mass))
+            print('Total mass MGE %#.4g:' % np.sum(mass))
 
         if plot:
 
