@@ -479,9 +479,9 @@ def jam_sph_rms(surf_lum, sigma_lum, surf_pot, sigma_pot, mbh, distance, rad,
         chi2 = np.sum(((rms - rmsModel)/erms)**2) / rms.size
 
         if not quiet:
-            print('beta[0]=%.2f; M/L=%.3f; BH=%.3g; chi2/DOF=%.3g'
+            print('beta[0]=%.2f; M/L=%#.3g; BH=%#.3g; chi2/DOF=%#.3g'
                 % (beta[0], ml, mbh*ml, chi2))
-            print('Total mass MGE: %.4g' % np.sum(mass*ml))
+            print('Total mass MGE: %#.4g' % np.sum(mass*ml))
 
         if plot:
             rad1 = rad.clip(0.38*pixsize)
